<?php
/** Corsican (Corsu)
 *
 * @ingroup Language
 * @file
 *
 */

$messages = array(
'underline-always' => 'Sempre',
'underline-never'  => 'Mai',

# Dates
'sunday'        => 'dumenica',
'monday'        => 'luni',
'tuesday'       => 'marti',
'wednesday'     => 'mercuri',
'thursday'      => 'ghjovi',
'friday'        => 'venneri',
'saturday'      => 'sabbatu',
'sun'           => 'dum',
'mon'           => 'lun',
'tue'           => 'mar',
'wed'           => 'mer',
'thu'           => 'ghj',
'fri'           => 'ven',
'sat'           => 'sab',
'january'       => 'ghjennaghju',
'february'      => 'ferraghju',
'march'         => 'marzu',
'april'         => 'aprile',
'may_long'      => 'maghju',
'june'          => 'ghjugnu',
'july'          => 'lugliu',
'august'        => 'aostu',
'september'     => 'settembre',
'october'       => 'ottobre',
'november'      => 'nuvembre',
'december'      => 'dicembre',
'january-gen'   => 'ghjennaghju',
'february-gen'  => 'ferraghju',
'march-gen'     => 'marzu',
'april-gen'     => 'aprile',
'may-gen'       => 'maghju',
'june-gen'      => 'ghjugnu',
'july-gen'      => 'lugliu',
'august-gen'    => 'aostu',
'september-gen' => 'settembre',
'october-gen'   => 'ottobre',
'november-gen'  => 'nuvembre',
'december-gen'  => 'dicembre',
'jan'           => 'ghje',
'feb'           => 'fer',
'mar'           => 'mar',
'apr'           => 'apr',
'may'           => 'mag',
'jun'           => 'ghju',
'jul'           => 'lug',
'aug'           => 'aos',
'sep'           => 'set',
'oct'           => 'ott',
'nov'           => 'nuv',
'dec'           => 'dic',

# Categories related messages
'pagecategories'  => '{{PLURAL:$1|Categuria|Categurie}}',
'category_header' => 'Articuli in a categuria "$1"',
'subcategories'   => 'Sottucategurie',

'about'          => 'À prupositu',
'article'        => 'Articulu',
'cancel'         => 'Annullà',
'qbpageoptions'  => 'Issa pagina',
'qbpageinfo'     => 'Cuntestu',
'qbmyoptions'    => 'E mo pagine',
'qbspecialpages' => 'Pagine spiciale',
'mypage'         => 'A mo pagina',
'mytalk'         => 'E mo discussioni',
'anontalk'       => 'Discussione per istu indirizzu IP',
'navigation'     => 'Navigazione',
'and'            => '&#32;è',

'errorpagetitle'   => 'Errore',
'returnto'         => 'Vultà à $1.',
'help'             => 'Aiutu',
'search'           => 'Ricerca',
'searchbutton'     => 'Ricerca',
'searcharticle'    => 'Và',
'history'          => 'Cronolugia',
'history_short'    => 'Cronolugia',
'info_short'       => 'Infurmazione',
'permalink'        => 'Ligame permanente',
'print'            => 'Stampà',
'edit'             => 'Mudificà',
'create'           => 'Creà',
'delete'           => 'Supprimà',
'deletethispage'   => 'Cancellà issa pagina',
'protect'          => 'Pruteghje',
'protectthispage'  => 'Pruteghje issa pagina',
'newpage'          => 'Pagina nova',
'talkpagelinktext' => 'discussione',
'specialpage'      => 'Pagina speciale',
'articlepage'      => "Vede l'articulu",
'talk'             => 'Discussione',
'toolbox'          => 'Stuvigli',
'userpage'         => 'Vede a pagina di utilizatore',
'otherlanguages'   => 'In altri lingui',
'lastmodifiedat'   => 'Ultima mudifica di ista pagina u $1 à e $2.', # $1 date, $2 time
'protectedpage'    => 'Pagina prutetta',
'jumptonavigation' => 'navigazione',
'jumptosearch'     => 'ricerca',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'À prupositu di {{SITENAME}}',
'aboutpage'            => 'Project:À prupositu',
'currentevents'        => 'Ultimi evenimenti',
'currentevents-url'    => 'Project:Ultimi evenimenti',
'disclaimers'          => 'Avertimenti',
'disclaimerpage'       => 'Project:Avertimenti generali',
'mainpage'             => 'Pagina maestra',
'mainpage-description' => 'Pagina maestra',
'portal'               => 'Purtone di a cumunità',
'portal-url'           => 'Project:Purtone di a cumunità',
'privacy'              => 'Pulitica pè a riservatezza',
'privacypage'          => 'Project:Pulitica pè a riservatezza',

'versionrequired' => 'A version $1 di MediaWiki hè necessaria',

'newmessagesdifflink' => 'ultima mudifica',
'editsection'         => 'mudificà',
'editold'             => 'mudificà',
'toc'                 => 'Cuntenutu',
'showtoc'             => 'mustrà',
'hidetoc'             => 'piattà',
'feed-atom'           => 'Atomu',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Articulu',
'nstab-user'      => 'Utilizatore',
'nstab-image'     => 'Schedariu',
'nstab-mediawiki' => 'Messaghju',
'nstab-template'  => 'Mudellu',
'nstab-help'      => "Pagina d'aiutu",
'nstab-category'  => 'Categuria',

# General errors
'error'         => 'Errore',
'internalerror' => 'Errore internu',
'viewsourcefor' => 'di $1',

# Login and logout pages
'yourname'                   => 'Nome di utilizatore:',
'yourpassword'               => 'Parulla secreta:',
'yourpasswordagain'          => 'Scrive torna a parulla secreta:',
'yourdomainname'             => 'U to duminiu:',
'login'                      => 'Cunnessione',
'userlogin'                  => 'Cunnessione / Registramentu',
'logout'                     => 'Scunnessione',
'userlogout'                 => 'Scunnessione',
'nologinlink'                => 'Registramentu',
'createaccount'              => 'Registramentu',
'gotaccountlink'             => 'Cunnessione',
'youremail'                  => 'Indirizzu e-mail:',
'yourrealname'               => 'U to veru nome:',
'yourlanguage'               => "Lingua di l'interfaccia:",
'yourvariant'                => 'Variante',
'yournick'                   => 'Signatura pè e discussioni:',
'loginsuccesstitle'          => 'Cunnessione fatta',
'acct_creation_throttle_hit' => "Desulatu, ai digià fattu $1 registramenti. Ùn ne poi micca fà d'altri.",
'accountcreated'             => 'Registramentu fattu',
'accountcreatedtext'         => "U registramentu di l'utilizatore $1 hè statu fattu.",
'loginlanguagelabel'         => 'Lingua: $1',

# Password reset dialog
'retypenew' => 'Scrive torna a nova parulla secreta:',

# Edit page toolbar
'image_sample' => 'Esempiu.jpg',

# Edit pages
'minoredit'              => 'Mudifica minore',
'savearticle'            => 'Arrighjistrà a pagina',
'showdiff'               => 'Mustrà i cambiamenti',
'anoneditwarning'        => "'''Attenzione''': ùn sè micca un utilizatore registratu, oppuru ùn ai fattu a cunnessione.
U to indirizzu IP serà registratu indu a cronolugia di ista pagina.",
'loginreqlink'           => 'cunnessione',
'accmailtitle'           => 'Parulla secreta inviata.',
'accmailtext'            => 'A parulla secreta per "$1" hè stata inviata à l\'indirizzu $2.',
'editing'                => 'Mudifica di $1',
'editingsection'         => 'Mudifica di $1 (sezzione)',
'editingcomment'         => 'Mudifica di $1 (cummentu)',
'editconflict'           => 'Cunflittu di mudificazione: $1',
'yourtext'               => 'U to testu',
'yourdiff'               => 'Differenze',
'template-protected'     => '(prutettu)',
'template-semiprotected' => '(mezu prutettu)',
'nocreatetitle'          => 'Creazione di pagina limitata',

# Account creation failure
'cantcreateaccounttitle' => 'Registramentu micca pussibile',

# History pages
'currentrev'  => 'Ultima revisione',
'page_first'  => 'prima',
'deletedrev'  => '[supprimatu]',
'histfirst'   => 'Prima',
'histlast'    => 'Ultima',
'historysize' => '({{PLURAL:$1|1 ottettu|$1 ottetti}})',

# Revision feed
'history-feed-title' => 'Cronolugia di e revisione',

# Revision deletion
'rev-delundel' => 'mustrà/piattà',

# Search results
'searchresults' => 'Risultati di a ricerca',
'powersearch'   => 'Ricerca',

# Preferences page
'preferences'       => 'Preferenze',
'mypreferences'     => 'Preferenze',
'math'              => 'Matematica',
'math_syntax_error' => 'errore di sintassa',
'prefs-rc'          => 'Ultimi cambiamenti',
'prefs-watchlist'   => 'Articuli seguitati',
'columns'           => 'Culonne:',
'searchresultshead' => 'Ricerca',
'localtime'         => 'Ora lucale',
'allowemail'        => 'Abilità a ricezzione di e-mail da altri utilizatori',
'files'             => 'Schedarii',

# User rights
'editinguser'             => "Mudifica di '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]]{{int:pipe-separator}}[[Special:Contributions/$1|{{int:contribslink}}]])",
'userrights-groupsmember' => 'Membru di:',

# Groups
'group'            => 'Gruppu:',
'group-bot'        => 'Boti',
'group-sysop'      => 'Amministratori',
'group-bureaucrat' => 'Burocrati',
'group-all'        => '(tutti)',

'group-bot-member'        => 'Botu',
'group-sysop-member'      => 'Amministratore',
'group-bureaucrat-member' => 'Burocratu',

'grouppage-bot'        => '{{ns:project}}:Boti',
'grouppage-sysop'      => '{{ns:project}}:Amministratori',
'grouppage-bureaucrat' => '{{ns:project}}:Burocrati',

# Recent changes
'recentchanges'   => 'Ultimi cambiamenti',
'rcnotefrom'      => "Quì sò discritti i cambiamenti dipoi <b>$2</b> (sin'à <b>$1</b>).",
'rclistfrom'      => 'Mustrà i cambiamenti dipoi $1',
'rcshowhideminor' => '$1 i cambiamenti minori',
'rcshowhidebots'  => '$1 i boti',
'rcshowhideliu'   => "$1 l'utilizatori registrati",
'rcshowhideanons' => '$1 i cuntributori anonimi',
'rcshowhidemine'  => '$1 e mo cuntribuzioni',
'rclinks'         => 'Mustrà ultimi $1 cambiamenti in i $2 ghjorni scorsi<br />$3',
'hist'            => 'cron',
'hide'            => 'piattà',
'show'            => 'mustrà',

# Recent changes linked
'recentchangeslinked' => 'Cambiamenti assuciati',

# Upload
'upload'     => 'Incaricà un schedariu',
'uploadbtn'  => 'Incaricà un schedariu',
'filename'   => 'Nome di u schedariu',
'filestatus' => "Statu di u dirittu d'autore:",

'upload-file-error' => 'Errore internu',

# Special:ListFiles
'imgfile'        => 'schedariu',
'listfiles_date' => 'Data',
'listfiles_name' => 'Nome',
'listfiles_user' => 'Utilizatore',

# File description page
'filehist'         => "Cronolugia di l'imagine",
'filehist-user'    => 'Utilizatore',
'imagelinks'       => 'Ligami',
'noimage-linktext' => 'incaricà lu',

# Unused templates
'unusedtemplateswlh' => 'altri ligami',

# Random page
'randompage' => 'Pagina à casu',

# Statistics
'statistics'              => 'Statistiche',
'statistics-header-users' => "Statistiche nant'à l'utilizatori",

'brokenredirects-edit' => '(mudificà)',

# Miscellaneous special pages
'ncategories'       => '$1 {{PLURAL:$1|categuria|categurie}}',
'specialpage-empty' => 'Issa pagina hè biota.',
'popularpages'      => 'Pagine populare',
'shortpages'        => 'Pagine corte',
'longpages'         => 'Pagine longhe',
'protectedpages'    => 'Pagine prutette',
'listusers'         => 'Listinu di i cuntributori',
'newpages'          => 'Pagine nove',
'ancientpages'      => 'Pagine vechje',

# Special:Log
'specialloguserlabel'  => 'Utilizatore:',
'speciallogtitlelabel' => 'Titulu:',
'all-logs-page'        => "Tutte l'azzioni",

# Special:AllPages
'allpages'          => 'Tutte e pagine',
'alphaindexline'    => 'da $1 à $2',
'allpagesfrom'      => 'Mustrà e pagine à parte da:',
'allarticles'       => "Tutti l'articuli",
'allinnamespace'    => 'Tutte e pagine di u spaziu $1',
'allnotinnamespace' => 'Tutte e pagine micca di u spaziu $1',
'allpagesprev'      => 'Precedenti',
'allpagesnext'      => 'Seguenti',
'allpagessubmit'    => 'Và',
'allpagesprefix'    => 'Mustrà e pagine chì cumincianu cù:',
'allpages-bad-ns'   => 'U spaziu "$1" ùn esiste micca nant\'à {{SITENAME}}',

# Special:Categories
'categories' => 'Categurie',

# Special:LinkSearch
'linksearch-ns' => 'Spaziu:',
'linksearch-ok' => 'Ricerca',

# Special:ListUsers
'listusers-submit' => 'Mustrà',

# E-mail user
'emailto'      => 'À',
'emailsubject' => 'Sughjettu',
'emailmessage' => 'Messaghju',
'emailsend'    => 'Invià',

# Watchlist
'watchlist'    => 'Articuli seguitati',
'mywatchlist'  => 'Articuli seguitati',
'watchlistfor' => "(di l'ultizatore '''$1''')",
'addedwatch'   => "Aghjuntu à u listinu di l'articuli seguitati",
'watch'        => 'Seguità',

'enotif_reset'       => 'Marcà tutte e pagine visitate',
'enotif_newpagetext' => 'Ista hè una pagina nova.',
'changed'            => 'cambiatu',
'created'            => 'creatu',

# Delete
'deletepage'      => 'Supprimà a pagina',
'excontent'       => "u cuntenutu era: '$1'",
'excontentauthor' => "u cuntenutu era: '$1' (è u solu cuntributore era '[[Special:Contributions/$2|$2]]')",
'exblank'         => 'a pagina era biota',
'actioncomplete'  => 'Azzione compia',

# Protect
'protectedarticle'            => 'prutettu "[[$1]]"',
'prot_1movedto2'              => 'hà mossu [[$1]] à [[$2]]',
'protect-legend'              => 'Cunfirmà a prutezzione',
'protect-level-autoconfirmed' => 'Bluccà i cuntributori micca arrighjistrati',

# Restrictions (nouns)
'restriction-create' => 'Creà',

# Restriction levels
'restriction-level-autoconfirmed' => 'mezu prutettu',

# Undelete
'viewdeletedpage'        => 'Fighjulà e p agine supprimate',
'undeletecomment'        => 'Cummentu:',
'undelete-search-box'    => 'Circà e pagine supprimate',
'undelete-search-submit' => 'Ricerca',

# Namespace form on various pages
'namespace'      => 'Spaziu:',
'blanknamespace' => '(Principale)',

# Contributions
'contributions' => "Cuntribuzioni di l'utilizatore",
'mycontris'     => 'E mo cuntribuzioni',
'contribsub2'   => 'Per $1 ($2)',
'month'         => 'Da u mese (è nanzu):',

# What links here
'istemplate' => 'inclusione',

# Block/unblock
'ipaddress'                => 'Adrizzu IP',
'ipadressorusername'       => 'Adrizzu IP o nome di cuntributore',
'ipblocklist-submit'       => 'Ricerca',
'blocklistline'            => '$1, $2 bluccati $3 ($4)',
'anononlyblock'            => 'solu i cuntributori anonimi',
'blocklink'                => 'bluccà',
'unblocklink'              => 'sbluccà',
'contribslink'             => 'cuntribuzioni',
'block-log-flags-anononly' => 'solu cuntributori anonimi',
'block-log-flags-nocreate' => 'registramentu pruibitu',
'proxyblocksuccess'        => 'Hè fattu.',

# Move page
'move-page-legend'        => 'Move a pagina',
'movearticle'             => 'Move a pagina',
'move-watch'              => 'Fighjulà issa pagina',
'movepagebtn'             => 'Move a pagina',
'movedto'                 => 'mossu à',
'1movedto2'               => 'hà mossu [[$1]] à [[$2]]',
'1movedto2_redir'         => 'hà reindirizzatu [[$1]] à [[$2]]',
'movelogpagetext'         => 'Elencu di e pagine mosse.',
'movereason'              => 'Mutivu',
'delete_and_move_confirm' => 'Iè, supprimà issa pagina',

# Export
'export'        => 'Espurtà pagine',
'export-submit' => 'Espurtà',
'export-addcat' => 'Aghjunghje',

# Namespace 8 related
'allmessages'               => 'Messaghji di sistemu',
'allmessagesname'           => 'Nome',
'allmessagesdefault'        => 'Testu prestabilitu',
'allmessagescurrent'        => 'Testu attuale',
'allmessagestext'           => 'Istu hè u listinu di tutti i messaghji dispunibili in u spaziu MediaWiki.',
'allmessagesnotsupportedDB' => "'''{{ns:special}}:Allmessages''' ùn hè dispunibile perchè '''\$wgUseDatabaseMessages''' ùn hè micca attivu.",
'allmessagesfilter'         => "Filtru nant'à i messaghji:",
'allmessagesmodified'       => 'Mustrà solu i mudificati',

# Special:Import
'import-interwiki-submit' => 'Impurtà',
'importnopages'           => 'Micca pagine da impurtà.',
'importfailed'            => 'Importu fiascatu: $1',

# Import log
'importlogpage'                 => 'Importu log',
'import-logentry-upload-detail' => '$1 {{PLURAL:$1|revisione|revisione}}',

# Tooltip help for the actions
'tooltip-pt-userpage'    => 'A to pagina di utilizatore',
'tooltip-pt-mytalk'      => 'A to pagina di discussione',
'tooltip-pt-preferences' => 'E to preferenze',
'tooltip-pt-watchlist'   => 'U listinu di e pagine chì seguiti',
'tooltip-pt-mycontris'   => 'U listinu di e to cuntribuzioni',
'tooltip-pt-login'       => 'U registramentu hè suggeritu, micca ubligatoriu',
'tooltip-pt-logout'      => 'Scunnessione',
'tooltip-ca-protect'     => 'Pruteghje issa pagina',
'tooltip-ca-delete'      => 'Supprimà issa pagina',
'tooltip-p-logo'         => 'Pagina maestra',
'tooltip-n-mainpage'     => 'Andà à a Pagina maestra',
'tooltip-t-specialpages' => 'Listinu di tutte e pagine spiciale',
'tooltip-ca-nstab-user'  => 'Vede a pagina di utilizatore',

# Attribution
'anonymous' => 'Utilizatore(/i) anonimu(/i) di {{SITENAME}}',
'others'    => 'altri',

# Media information
'show-big-image' => 'Imagine in alta resoluzione',

# Special:NewFiles
'showhidebots' => '($1 boti)',
'noimages'     => 'Nulla da vede.',
'ilsubmit'     => 'Ricerca',
'bydate'       => 'per data',

# EXIF tags
'exif-orientation'      => 'Orientazione',
'exif-imagedescription' => "Titulu di l'imagine",
'exif-artist'           => 'Autore',
'exif-usercomment'      => "Cummenti di l'utilizatore",

'exif-orientation-1' => 'Nurmale', # 0th row: top; 0th column: left

'exif-componentsconfiguration-0' => 'ùn esiste micca',

'exif-meteringmode-255' => 'Altru',

'exif-scenecapturetype-2' => 'Ritrattu',

'exif-contrast-0' => 'Nurmale',

'exif-saturation-0' => 'Nurmale',

# 'all' in various places, this might be different for inflected languages
'imagelistall'  => 'tutte',
'watchlistall2' => 'tutti',
'monthsall'     => 'tutti',

# action=purge
'confirm_purge_button' => "D'accordu",

# Table pager
'table_pager_next'  => 'Prossima pagina',
'table_pager_first' => 'Prima pagina',
'table_pager_last'  => 'Ultima pagina',
'table_pager_empty' => 'Micca risultati',

# Auto-summaries
'autoredircomment' => 'Reindirizzamentu à [[$1]]',
'autosumm-new'     => 'Pagina nova: $1',

# Watchlist editor
'watchlistedit-raw-titles' => 'Pagine:',

# Special:Version
'version' => 'Versione', # Not used as normal message but as header for the special page itself

# Special:FilePath
'filepath-page' => 'Schedariu:',

# Special:SpecialPages
'specialpages' => 'Pagine spiciale',

);
